# IRIDA_uploader_cl

## IRIDA_uploader_cl is used to upload NGS sequences to irida system.

#### This tool is developed by National Microbiology Laboratory (NML) and redistributed by BCCDC William Hsiao's lab.


